@@ -45,7 +45,7 @@ def developer_contact():
 
 def showHistory():
     """Prints the information of all last sent messages using this program"""
-    file = open("pywhatkit_txtfile.txt","r")
+    file = open("pywhatkit_dbs.txt","r")
     content = file.read()
     file.close()
     if content == "--------------------":
@@ -58,7 +58,7 @@ Warning! This will clear pywhatkit.history()"""
     try:
         driver = webdriver.Chrome(path)
         driver.quit()
-        file = open("pywhatkit_txtfile.txt","w")
+        file = open("pywhatkit_dbs.txt","w")
         file.write("selpath : "+path+"\n")
         file.write("--------------------\n")
         file.close()
@@ -110,7 +110,7 @@ def load_QRcode():
 This is one time only, session will be saved
 ***You must call pywhatkit.add_driver_path(path) before callig this function"""
     global curpth
-    with open("pywhatkit_txtfile.txt") as file:
+    with open("pywhatkit_dbs.txt") as file:
         for lines in file:
             if "selpath" in lines:
                 path = lines.replace("selpath : ","")
@@ -142,7 +142,7 @@ Make sure whatsapp web is not already opened or you might get your number banned
         raise CountryCodeException("Country code missing from phone_no")
     timehr = time_hour
 
-    with open("pywhatkit_txtfile.txt") as file:
+    with open("pywhatkit_dbs.txt") as file:
         for lines in file:
             if "selpath" in lines:
                 path = lines.replace("selpath : ","")
@@ -171,7 +171,7 @@ Make sure whatsapp web is not already opened or you might get your number banned
 
     date = "%s:%s:%s"%(curr.tm_mday,curr.tm_mon,curr.tm_year)
     time_write = "%s:%s"%(timehr,time_min)
-    file = open("pywhatkit_txtfile.txt","a")
+    file = open("pywhatkit_dbs.txt","a")
     file.write("Date: %s\nTime: %s\nPhone number: %s\nMessage: %s"%(date,time_write,phone_no,message))
     file.write("\n--------------------\n")
     file.close()
@@ -207,7 +207,7 @@ def send_file(phone_no, path_to_file, time_hour, time_min, print_messages=True):
     if not os.path.exists(path_to_file):
         raise FilePathException("No file found at %s"%path_to_file)
 
-    with open("pywhatkit_txtfile.txt") as file:
+    with open("pywhatkit_dbs.txt") as file:
         for lines in file:
             if "selpath" in lines:
                 chrpath = lines.replace("selpath : ","")
@@ -236,7 +236,7 @@ def send_file(phone_no, path_to_file, time_hour, time_min, print_messages=True):
 
     date = "%s:%s:%s"%(curr.tm_mday,curr.tm_mon,curr.tm_year)
     time_write = "%s:%s"%(timehr,time_min)
-    file = open("pywhatkit_txtfile.txt","a")
+    file = open("pywhatkit_dbs.txt","a")
     file.write("Date: %s\nTime: %s\nPhone number: %s\nAttachment: %s"%(date,time_write,phone_no,path_to_file))
     file.write("\n--------------------\n")
     file.close()
@@ -299,7 +299,7 @@ first check it by calling 'check_window()' function'''
     
     date = "%s:%s:%s"%(curr.tm_mday,curr.tm_mon,curr.tm_year)
     time_write = "%s:%s"%(timehr,time_min)
-    file = open("pywhatkit_txtfile.txt","a")
+    file = open("pywhatkit_dbs.txt","a")
     file.write("Date: %s\nTime: %s\nPhone number: %s\nMessage: %s"%(date,time_write,phone_no,message))
     file.write("\n--------------------\n")
     file.close()
@@ -322,28 +322,21 @@ def info(topic,lines=3):
 def playonyt(topic):
     """Will play video on following topic, takes about 10 to 15 seconds to load"""
     url = 'https://www.youtube.com/results?q=' + topic
-    options = webdriver.ChromeOptions()
-    options.add_argument("--headless")
-    try:
-        with open("pywhatkit_txtfile.txt") as file:
-            for lines in file:
-                    if "selpath" in lines:
-                        path = lines.replace("selpath : ","")
-            path = path.strip()
-        driver = webdriver.Chrome(path,options=options)
-    except:
-        raise Exception("Chrome driver not found, call pywhatkit.help()")
-    req = driver.get(url)
-    sctext = driver.page_source
-    driver.quit()
-    soup = BeautifulSoup(sctext,"html.parser")
-    try:
-        songs = soup.findAll("a",{"id":"video-title"})
-        song = songs[0]
-        songurl = song['href']
-        web.open("https://www.youtube.com"+songurl)
-    except:
-        raise Exception("Video not found")
+    count = 0
+    cont = requests.get(url)
+    data = cont.content
+    data = str(data)
+    lst = data.split('"')
+    for i in lst:
+        count+=1
+        if i == 'WEB_PAGE_TYPE_WATCH':
+            break
+    if lst[count-5] == "/results":
+        raise Exception("No video found.")
+    
+    #print("Videos found, opening most recent video")
+    web.open("https://www.youtube.com"+lst[count-5])
+    return "https://www.youtube.com"+lst[count-5]
 
 def search(topic):
     '''Searches about the topic on Google'''
@@ -352,17 +345,7 @@ def search(topic):
 
 def help():
     """User manual of pywhatkit library"""
-    print("""How to use the new functions:
-
-NOTE : To use new functions, you must have Google Chrome installed and updated
-1. Download and extract the current stable release of chromedriver from https://chromedriver.chromium.org/.
-2. Open the downloaded file and search for an application named chromedrive, copy its path,
-   for windows, it should look like this - C:/Users/.../chromedriver.exe.
-3. Call pywhatkit.add_driver_path(path) and pass the copied path as argument, if path is valid, a black window along with chrome will open and close
-4. Now call pywhatkit.load_QRcode() function and scan the QR code.
-5. You are all set. Now call the desired function. All the information have been saved and you don't to do the same thing again.
-
-
+    print("""
 SOME COMMON ERRORS and HOW TO FIX THEM:
 
 1. CountryCodeException("Country code missing from phone_no")
@@ -393,15 +376,15 @@ if tyme >= 5:
         raise Warning("INTERNET IS SLOW, extraction of information might take longer time")
 
 try :
-    file = open("pywhatkit_txtfile.txt","r")
+    file = open("pywhatkit_dbs.txt","r")
     file.close()
 
 except:
-    file = open("pywhatkit_txtfile.txt","w")
-    print("""Hello from the creator of pywhatkit, Ankit Raj Mahapatra.\nKindly do report bug if any
+    file = open("pywhatkit_dbs.txt","w")
+    print("""Hello from the creator of pywhatkit, Ankit Raj Mahapatra.\nKindly do report bugs if any
 What's new:
-1. Fixed playonyt() function.
-2. Added some new functions, to know how to use them check pywhatkit.help().""")
+1. Fixed playonyt() function, now you no longer need chromedriver and this version is the fastest of all.
+2. Added pywhatkit.help() for fixing some common errors.""")
     file.write("--------------------\n")
     file.close()
     file = None
